..
    Copyright (C) 2022 Graz University of Technology.

    invenio-workflows-tugraz is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Authors
=======

This package is used to implement the workflows of the tu graz repository.

- Graz University of Technology <info@tugraz.at>
